# RQDATAC: Ricequant Data Client

**rqdatac** is a python package providing financial data from trusted sources, free you 
from IT maintenance or data cleansing tasks for financial institutions.

It provides with audited data in formatted data structure via thoughtfully designed APIs so to 
improve efficiency in data processing.

## Get Start
- [Init](https://www.ricequant.com/doc/rqdata-institutional#research-init)
- [API Doc](https://www.ricequant.com/doc/rqdata-institutional#research-API)
- [Change Log](https://www.ricequant.com/doc/rqdata-institutional#research-init)

## Have A Try
- Get free access to [RQData](https://www.ricequant.com/welcome/trial/rqdata-cloud ).
- Learn more [details](https://www.ricequant.com/welcome/rqdata).
